@@ -9,7 +9,7 @@ def main():
     else:
         dbfile = incache('labelme3.h5')
     
-    db = Viset(dbfile, datastep=100, verbose=True, asyncread=False)
+    db = Viset(dbfile, datastep=100, verbose=True, async=False)
     for (im,annotation) in db[0]:
         print 'Image=' + str(annotation['id_img']) + ' Category=' + annotation['category']
         if im is not None:
