@@ -24,12 +24,13 @@ class Cache():
     _cachesize = None  # async result
     _prettyhash = True
     
-    def __init__(self, cacheroot=_cacheroot, maxsize=10E9, verbose=False, strategy='lru'):
+    def __init__(self, cacheroot=_cacheroot, maxsize=10E9, verbose=False, strategy='lru', refetch=True):
         if cacheroot is not None:
             self._cacheroot = cacheroot
         self._maxsize = maxsize
         self._verbose = verbose
         self._strategy = strategy
+        self._refetch = refetch
             
     def __len__(self):
         if self._cachesize is not None:
@@ -55,13 +56,13 @@ class Cache():
         return opt
   
     def read(self, filename, reader=None, id=None):
-        quietprint('[viset.cache]: Reading ' + reader + ' encoded image ' + str(id) + ' from file "' + filename + '"', self._verbose)
+        quietprint('[viset.cache][HIT]: Reading ' + reader + ' encoded image ' + str(id) + ' from file "' + filename + '"', self._verbose)
         if reader == 'universal':
             return pylab.imread(filename)
         elif reader == 'mnist':
             return viset.mnist.imread(filename, int(id))
         else:
-            self.quietprint('[viset.cache]: reader type "' + str(reader) + '" unsupported', self._verbose)
+            self.quietprint('[viset.cache][ERROR]: reader type "' + str(reader) + '" unsupported', self._verbose)
             raise NotImplementedError()
         
     def unpack(self, filename, sha1=None, item=None):
@@ -87,14 +88,14 @@ class Cache():
         elif path.isdir(viset.util.splitextension(filename)[0]):
             obj = viset.util.splitextension(filename)[0]  # archive directory in cache
         elif isarchive(filename):
-            quietprint('[viset.cache]: archive file "' + filename + '" not unpacked to "' + (viset.util.splitextension(filename)[0]), self._verbose)
+            quietprint('[viset.cache][ERROR]: archive file "' + filename + '" not unpacked to "' + (viset.util.splitextension(filename)[0]), self._verbose)
             raise IOError()
         elif ishdf5(filename):
             obj = filename
         elif isfile(filename):
             obj = filename
         else:
-            quietprint('[viset.cache]: could not load filename "' + filename + '"', self._verbose)
+            quietprint('[viset.cache][ERROR]: could not load filename "' + filename + '"', self._verbose)
             raise IOError()
         return obj
         
@@ -131,7 +132,7 @@ class Cache():
             quietprint('[viset.cache][MISS]: downloading \'' + str(url[0:63] + '...') + '\'', self._verbose)                                        
             filename = self.download(url)
             if isarchive(filename):
-                quietprint('[viset.cache]: extracting archive \'' + filename + '\'', self._verbose)
+                quietprint('[viset.cache][MISS]: extracting archive \'' + filename + '\'', self._verbose)
                 if urlopts['item'] is not None:
                     filename = self.unpack(filename, sha1=urlopts['sha1'], item=urlopts['item'])
                 else:
@@ -139,7 +140,7 @@ class Cache():
         else:
             filename = self.cachefile(url)            
             quietprint('[viset.cache][HIT]: retrieving \'' + filename + '\'', self._verbose)                                     
-        quietprint('[viset.cache]: loading \'' + filename + '\'', self._verbose)                                         
+        quietprint('[viset.cache][HIT]: loading \'' + filename + '\'', self._verbose)                                         
         return self.load(filename, reader=urlopts['reader'], id=urlopts['id'])
     
     def get(self, url, sha1=None):
@@ -151,9 +152,12 @@ class Cache():
         except NotImplementedError:
             raise
         except:
-            quietprint('[viset.cache]: cache fetch error - discarding and refetching', self._verbose)                                                     
-            self.discard(url)
-            return self.fetch(url, sha1=sha1)
+            if self._refetch:
+                quietprint('[viset.cache][ERROR]: cache fetch error - discarding and refetching', self._verbose)                                                     
+                self.discard(url)
+                return self.fetch(url, sha1=sha1)
+            else:
+                raise
             
     def discard(self, url):
         """Remove element from cache"""
