@@ -188,6 +188,8 @@ class Viset(object):
 
     def delete(self):
         self.dbcache.delete()
+        # FIXME: this should delete the database also
+        
 
     def name(self):
         return self.dbobj.root._v_attrs.viset_name        
@@ -212,6 +214,10 @@ class Viset(object):
             viewlist.append(node.attrs.name)
         return viewlist
 
+    def views(self):
+        """List of views in database"""    
+        return self.list_views()
+    
     def num_views(self):
         """Total number of views in database"""
         return len(self.views())
@@ -269,7 +275,7 @@ class Viset(object):
         # Return newly created database for writing
         self.dbobj.flush()
         return self.dbobj
-
+    
         
 class CategorizationViset(Viset):
     _viewname = 'Categorization'
